@@ -6,8 +6,10 @@ import (
 	"strings"
 	"time"
 
+	"github.com/google/uuid"
 	"github.com/jandedobbeleer/oh-my-posh/src/log"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime/path"
 )
 
 const (
@@ -21,7 +23,7 @@ func getExecutablePath(env runtime.Environment) (string, error) {
 	}
 
 	if env.Flags().Strict {
-		return runtime.Base(env, executable), nil
+		return path.Base(executable), nil
 	}
 
 	// On Windows, it fails when the excutable is called in MSYS2 for example
@@ -49,21 +51,18 @@ func Init(env runtime.Environment, feats Features) string {
 			additionalParams += " --strict"
 		}
 
-		if env.Flags().Manual {
-			additionalParams += " --manual"
-		}
-
 		var command, config string
+
 		switch shell {
 		case PWSH, PWSH5:
 			command = "(@(& %s init %s --config=%s --print%s) -join \"`n\") | Invoke-Expression"
-			config = quotePwshStr(env.Flags().Config)
-			executable = quotePwshStr(executable)
 		case ELVISH:
-			command = "eval (%s init %s --config=%s --print%s | slurp)"
-			config = env.Flags().Config
+			command = "eval ((external %s) init %s --config=%s --print%s | slurp)"
 		}
 
+		config = quotePwshOrElvishStr(env.Flags().Config)
+		executable = quotePwshOrElvishStr(executable)
+
 		return fmt.Sprintf(command, executable, shell, config, additionalParams)
 	case ZSH, BASH, FISH, CMD, TCSH, XONSH:
 		return PrintInit(env, feats, nil)
@@ -71,7 +70,7 @@ func Init(env runtime.Environment, feats Features) string {
 		createNuInit(env, feats)
 		return ""
 	default:
-		return fmt.Sprintf("echo \"No initialization script available for %s\"", shell)
+		return fmt.Sprintf(`echo "%s is not supported by Oh My Posh"`, shell)
 	}
 }
 
@@ -83,41 +82,55 @@ func PrintInit(env runtime.Environment, features Features, startTime *time.Time)
 
 	shell := env.Flags().Shell
 	configFile := env.Flags().Config
+	sessionID := uuid.NewString()
 
 	var script string
 
 	switch shell {
 	case PWSH, PWSH5:
-		executable = quotePwshStr(executable)
-		configFile = quotePwshStr(configFile)
+		executable = quotePwshOrElvishStr(executable)
+		configFile = quotePwshOrElvishStr(configFile)
+		sessionID = quotePwshOrElvishStr(sessionID)
 		script = pwshInit
 	case ZSH:
-		executable = quotePosixStr(executable)
-		configFile = quotePosixStr(configFile)
+		executable = QuotePosixStr(executable)
+		configFile = QuotePosixStr(configFile)
+		sessionID = QuotePosixStr(sessionID)
 		script = zshInit
 	case BASH:
-		executable = quotePosixStr(executable)
-		configFile = quotePosixStr(configFile)
+		executable = QuotePosixStr(executable)
+		configFile = QuotePosixStr(configFile)
+		sessionID = QuotePosixStr(sessionID)
 		script = bashInit
 	case FISH:
 		executable = quoteFishStr(executable)
 		configFile = quoteFishStr(configFile)
+		sessionID = quoteFishStr(sessionID)
 		script = fishInit
 	case CMD:
-		executable = quoteLuaStr(executable)
-		configFile = quoteLuaStr(configFile)
+		executable = escapeLuaStr(executable)
+		configFile = escapeLuaStr(configFile)
+		sessionID = escapeLuaStr(sessionID)
 		script = cmdInit
 	case NU:
 		executable = quoteNuStr(executable)
 		configFile = quoteNuStr(configFile)
+		sessionID = quoteNuStr(sessionID)
 		script = nuInit
 	case TCSH:
-		executable = quotePosixStr(executable)
-		configFile = quotePosixStr(configFile)
+		executable = quoteCshStr(executable)
+		configFile = quoteCshStr(configFile)
+		sessionID = quoteCshStr(sessionID)
 		script = tcshInit
 	case ELVISH:
+		executable = quotePwshOrElvishStr(executable)
+		configFile = quotePwshOrElvishStr(configFile)
+		sessionID = quotePwshOrElvishStr(sessionID)
 		script = elvishInit
 	case XONSH:
+		executable = quotePythonStr(executable)
+		configFile = quotePythonStr(configFile)
+		sessionID = quotePythonStr(sessionID)
 		script = xonshInit
 	default:
 		return fmt.Sprintf("echo \"No initialization script available for %s\"", shell)
@@ -127,10 +140,13 @@ func PrintInit(env runtime.Environment, features Features, startTime *time.Time)
 		"::OMP::", executable,
 		"::CONFIG::", configFile,
 		"::SHELL::", shell,
+		"::SESSION_ID::", sessionID,
 	).Replace(script)
 
 	shellScript := features.Lines(shell).String(init)
 
+	log.Debug(shellScript)
+
 	if !env.Flags().Debug {
 		return shellScript
 	}
@@ -139,9 +155,6 @@ func PrintInit(env runtime.Environment, features Features, startTime *time.Time)
 
 	builder.WriteString(fmt.Sprintf("\n%s %s\n", log.Text("Init duration:").Green().Bold().Plain(), time.Since(*startTime)))
 
-	builder.WriteString(log.Text("\nScript:\n\n").Green().Bold().Plain().String())
-	builder.WriteString(shellScript)
-
 	builder.WriteString(log.Text("\n\nLogs:\n\n").Green().Bold().Plain().String())
 	builder.WriteString(env.Logs())
 
