@@ -14,6 +14,7 @@ func funcMap() template.FuncMap {
 		"path":         filePath,
 		"glob":         glob,
 		"matchP":       matchP,
+		"findP":        findP,
 		"replaceP":     replaceP,
 		"gt":           gt,
 		"lt":           lt,
@@ -21,6 +22,7 @@ func funcMap() template.FuncMap {
 		"reason":       GetReasonFromStatus,
 		"hresult":      hresult,
 		"trunc":        trunc,
+		"truncE":       truncE,
 		"readFile":     readFile,
 		"stat":         stat,
 		"dir":          filepath.Dir,
